--[[
    MyRolePlay 4 (C) 2010-2022 Etarna Moonshyne <etarna@moonshyne.org>, Katorie, Meorawr
    Licensed under GNU General Public Licence version 2 or, at your option, any later version

    UI_Options.lua - The options panel
]]

local L = mrp.L

local function mrp_HeaderColourChangedCallback(previousValues)
    local newR, newG, newB;
    if previousValues then
        -- The user bailed, we extract the old colour from the table created by mrp_ShowColorPicker.
		if mrp:IsMainlineClient() then
			newR = previousValues["r"]
			newG = previousValues["g"]
			newB = previousValues["b"]
		else
			newR, newG, newB = unpack(previousValues);
		end
        mrpSaved.Options["headerColour"]["r"] = newR
        mrpSaved.Options["headerColour"]["g"] = newG
        mrpSaved.Options["headerColour"]["b"] = newB
        MyRolePlayOptionsPanel_HeaderColourTexture:SetVertexColor(newR, newG, newB);
        return
    else
        -- Something changed
        newR, newG, newB = ColorPickerFrame:GetColorRGB();
    end
    -- Update our internal storage.
    local r, g, b = newR or 1, newG or 1, newB or 1 -- r, g, b, a should be whatever we wanna set in saved variables.
    if(type(mrpSaved.Options["headerColour"]) ~= "table") then -- If the current profile doesn't have an rgb table in the saved profile, make it.
        mrpSaved.Options["headerColour"] = {}
    end
    mrpSaved.Options["headerColour"]["r"] = r -- We're always using 1 as the alpha so no need to save opacity.
    mrpSaved.Options["headerColour"]["g"] = g
    mrpSaved.Options["headerColour"]["b"] = b
    -- And update any UI elements that use this colour...
    MyRolePlayOptionsPanel_HeaderColourTexture:SetVertexColor(r, g, b);
end

-- I love it when Blizzard do most of the hard work for me.
function mrp:CreateOptionsPanel()
    if not MyRolePlayOptionsPanel then
        local c = InterfaceOptionsFramePanelContainer
        local f = CreateFrame( "Frame", "MyRolePlayOptionsPanel", c )
        f:Hide()
        f:SetPoint( "TOPLEFT" , c, "TOPLEFT" )
        f:SetPoint( "BOTTOMRIGHT", c, "BOTTOMRIGHT" )

        f.name = "MyRolePlay"
        f.options = {
            enable = { text = L["opt_enable"], tooltip = L["opt_enable_tt"] },
            mrpbutton = { text = L["opt_mrpbutton"], tooltip = L["opt_mrpbutton_tt"] },
			profilevieweresc = { text = L["opt_profilevieweresc"], tooltip = L["opt_profilevieweresc_tt"] },
            allowcolours = { text = L["opt_allowcolours"], tooltip = L["opt_allowcolours_tt"] },
            tooltipclasscolours = { text = L["opt_tooltipclasscolours"], tooltip = L["opt_tooltipclasscolours_tt"] },
            increasecolourcontrast = { text = L["opt_increasecolourcontrast"], tooltip = L["opt_increasecolourcontrast_tt"] },
            classnames = { text = L["opt_classnames"], tooltip = L["opt_classnames_tt"] },
            showooc = { text = L["opt_showooc"], tooltip = L["opt_showooc_tt"] },
            showtarget = { text = L["opt_showtarget"], tooltip = L["opt_showtarget_tt"] },
            showiconintt = { text = L["opt_showiconintt"], tooltip = L["opt_showiconintt_tt"] },
            autoplaymusic = { text = L["opt_autoplaymusic"], tooltip = L["opt_autoplaymusic_tt"] },
            showversion = { text = L["opt_showversion"], tooltip = L["opt_showversion_tt"] },
            showfullversiontext = { text = L["opt_showfullversiontext"], tooltip = L["opt_showfullversiontext_tt"] },
            hidettinencounters = { text = L["opt_hidettinencounters"], tooltip = L["opt_hidettinencounters_tt"] },
			showlegacylevel = { text = L["opt_showlegacylevel"], tooltip = L["opt_showlegacylevel_tt"] },
			showpronouns = { text = L["opt_showpronouns"], tooltip = L["opt_showpronouns_tt"] },
			showvoicereference = { text = L["opt_showvoicereference"], tooltip = L["opt_showvoicereference_tt"] },
            showguildnames = { text = L["opt_showguildnames"], tooltip = L["opt_showguildnames_tt"] },
            maxlinesslider = { text = L["opt_maxlinesslider"], tooltip = L["opt_maxlinesslider_tt"] },
            showglancepreview = { text = L["opt_showglancepreview"], tooltip = L["opt_showglancepreview_tt"] },
            ttstyle = { },
			ttnamecolour = { },
            rpchatsay = { text = L["opt_rpchatnamesay"], tooltip = L["opt_rpchatnamesay_tt"] },
            rpchatwhisper = { text = L["opt_rpchatnamewhisper"], tooltip = L["opt_rpchatnamewhisper_tt"] },
            rpchatemote = { text = L["opt_rpchatnameemote"], tooltip = L["opt_rpchatnameemote_tt"] },
            rpchatyell = { text = L["opt_rpchatnameyell"], tooltip = L["opt_rpchatnameyell_tt"] },
            rpchatparty = { text = L["opt_rpchatnameparty"], tooltip = L["opt_rpchatnameparty_tt"] },
            rpchatraid = { text = L["opt_rpchatnameraid"], tooltip = L["opt_rpchatnameraid_tt"] },
            rpchatguild = { text = L["opt_rpchatnameguild"], tooltip = L["opt_rpchatnameguild_tt"] },
            highlightemotes = { text = L["opt_highlightemotes"], tooltip = L["opt_highlightemotes_tt"] },
            highlightooc = { text = L["opt_highlightooc"], tooltip = L["opt_highlightooc_tt"] },
            showiconsinchat = { text = L["opt_showiconsinchat"], tooltip = L["opt_showiconsinchat_tt"] },
            glanceposition = { },
            ahunit = { },
            awunit = { },
            formac = { text = L["opt_formac"] },
            equipac = { text = L["opt_equipac"], tooltip = L["opt_equipac_tt"] },
            biog = { text = L["opt_biog"], tooltip = L["opt_biog_tt"] },
            traits = { text = L["opt_traits"], tooltip = L["opt_traits_tt"] }
        }

        -- form auto change: Use the right tooltip for the job.
        if select( 2, UnitRace("player") ) == "Worgen" then
            if select( 2, UnitClass("player") ) == "DRUID" then
                f.options.formac.tooltip = L["opt_formac_tt_worgendruid"]
            elseif select( 2, UnitClass("player") ) == "PRIEST" then
                f.options.formac.tooltip = L["opt_formac_tt_worgenpriest"]
            elseif select( 2, UnitClass("player") ) == "WARLOCK" then
                f.options.formac.tooltip = L["opt_formac_tt_worgenwarlock"]
            else
                f.options.formac.tooltip = L["opt_formac_tt_worgen"]
            end
        else
            if select( 2, UnitClass("player") ) == "DRUID" then
                f.options.formac.tooltip = L["opt_formac_tt_druid"]
            elseif select( 2, UnitClass("player") ) == "SHAMAN" then
                f.options.formac.tooltip = L["opt_formac_tt_shaman"]
            elseif select( 2, UnitClass("player") ) == "PRIEST" then
                f.options.formac.tooltip = L["opt_formac_tt_priest"]
            elseif select( 2, UnitClass("player") ) == "WARLOCK" then
                f.options.formac.tooltip = L["opt_formac_tt_warlock"]
            else
                f.options.formac.tooltip = L["opt_formac_tt_disabled"]
            end
        end
        -- Save memory; we don't need them anymore
        L["opt_formac_tt"] = nil
        L["opt_formac_tt_druid"] = nil
        L["opt_formac_tt_shaman"] = nil
        L["opt_formac_tt_priest"] = nil
        L["opt_formac_tt_warlock"] = nil
        L["opt_formac_tt_suffix"] = nil
        L["opt_formac_tt_worgen"] = nil
        L["opt_formac_tt_worgendruid"] = nil
        L["opt_formac_tt_worgenshaman"] = nil
        L["opt_formac_tt_worgenpriest"] = nil
        L["opt_formac_tt_worgenwarlock"] = nil
        L["opt_formac_tt_worgensuffix"] = nil
        L["opt_formac_tt_disabled"] = nil
        L["opt_formac_tt_enabled1"] = nil

        f.title = f:CreateFontString( nil, "OVERLAY", "GameFontNormalHuge" )
        f.title:SetPoint( "TOPLEFT", 16, -5 )
        f.title:SetJustifyH( "LEFT" )
        f.title:SetJustifyV( "TOP" )
        f.title:SetText( "MyRolePlay" )

        f.ver = f:CreateFontString( nil, "OVERLAY", "GameFontNormalSmall" )
        f.ver:SetPoint( "TOP", f.title )
        f.ver:SetPoint( "RIGHT", f, -32, 0 )
        f.ver:SetJustifyH( "RIGHT" )
        f.ver:SetText( mrp.VerInfo )

        f.changelog = CreateFrame( "Button", nil, f, "UIPanelButtonTemplate" )
        f.changelog:SetPoint( "RIGHT", f.ver, "LEFT", -25, 0 )
        f.changelog:SetText( L["Change Log"] )
        f.changelog:SetWidth( 90 )
        f.changelog:SetScript( "OnEnter", function(self)
            GameTooltip:SetOwner( self, "ANCHOR_RIGHT" )
            GameTooltip:SetText( L["Show the change log / patch notes frame."], 1.0, 1.0, 1.0 )
        end )
        f.changelog:SetScript( "OnLeave", GameTooltip_Hide )
        f.changelog:SetScript("OnClick", function (self)
            mrp:FormatChangeLog() -- Setup and show changelog for a new version.
            MyRolePlayChangeLogFrame:Show();
        end )
		
		-- Create template checkboxes
		local function newCheckbox(label, description, onClick)
			local check = CreateFrame("CheckButton", "MyRolePlayOptionsPanel_" .. label, f, "InterfaceOptionsCheckButtonTemplate")
			check:SetScript("OnClick", function(self)
				local tick = self:GetChecked()
				onClick(self, tick and true or false)
				if tick then
					PlaySound(856) -- SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_ON
				else
					PlaySound(857) -- SOUNDKIT.IG_MAINMENU_OPTION_CHECKBOX_OFF
				end
			end)
			check.label = _G[check:GetName() .. "Text"]
			check.label:SetText("|cffFFFFFF" .. label)
			check.label:SetTextScale(1.2)
			check.tooltipText = label
			check.tooltipRequirement = description
			check:SetScript( "OnEnter", function(self)
				--GameTooltip:SetOwner( self, "ANCHOR_RIGHT" )
				--GameTooltip:SetText( description, 1.0, 1.0, 1.0 )
				GameTooltip:SetOwner( self, "ANCHOR_RIGHT" )
				GameTooltip:SetText( label, 0.97, 0.80, 0.05 )
				GameTooltip:AddLine( description, 1.0, 1.0, 1.0, true )
				GameTooltip:Show()
			end )
			check:SetScript( "OnLeave", GameTooltip_Hide )
						
			return check
		end

        -- "Basic Functionality" header
        f.BasicFunctionalityHeader = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
        f.BasicFunctionalityHeader:SetJustifyH( "LEFT" )
        f.BasicFunctionalityHeader:SetJustifyV( "TOP" )
        f.BasicFunctionalityHeader:SetPoint( "TOPLEFT", f.title, "BOTTOMLEFT", 0, -10 )
        f.BasicFunctionalityHeader:SetText( L["opt_basicfunctionality_header"] )
		
        -- Enable / Disable MRP button
		f.mrpbutton = newCheckbox(
			L["opt_mrpbutton"], -- Label
			L["opt_mrpbutton_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ShowButton = value;
			if value == true then
				mrpSaved.Options.ShowButton = true
				mrp:TargetChanged() -- will display button if appropriate
			else
				mrpSaved.Options.ShowButton = false
				MyRolePlayButton:Hide()
			end;
		end)
		f.mrpbutton:SetChecked(mrpSaved.Options.ShowButton)
		f.mrpbutton:SetPoint( "TOPLEFT", f.BasicFunctionalityHeader, "BOTTOMLEFT", -2, -5 )
		

        -- Show glance preview box
		f.showglancepreview = newCheckbox(
			L["opt_showglancepreview"], -- Label
			L["opt_showglancepreview_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ShowGlancePreview = value 
		end)
		f.showglancepreview:SetChecked(mrpSaved.Options.ShowGlancePreview)
		f.showglancepreview:SetPoint( "TOPLEFT", f.mrpbutton, "BOTTOMLEFT", 0, 2 )
		
		-- Close profile viewer when ESC pressed
		f.profilevieweresc = newCheckbox(
			L["opt_profilevieweresc"], -- Label
			L["opt_profilevieweresc_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ProfileViewerESC = value;
			if value == true then
				if MyRolePlayBrowseFrame then
					tinsert(UISpecialFrames, "MyRolePlayBrowseFrame");
				end;
			else
				if MyRolePlayBrowseFrame then
					tremove(UISpecialFrames, tIndexOf(UISpecialFrames, "MyRolePlayBrowseFrame"));
				end;
			end;
		end)
		f.profilevieweresc:SetChecked(mrpSaved.Options.ProfileViewerESC)
		f.profilevieweresc:SetPoint( "TOPLEFT", f.showglancepreview, "BOTTOMLEFT", 0, 2 )

        -- Allow colours in profiles / tooltip
		f.allowcolours = newCheckbox(
			L["opt_allowcolours"], -- Label
			L["opt_allowcolours_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.AllowColours = value;
			if value == true then
				mrpSaved.Options.AllowColours = true
                f.tooltipclasscolours:Enable();
                f.increasecolourcontrast:Enable();
			else
				mrpSaved.Options.AllowColours = false
                f.tooltipclasscolours:Disable();
                f.increasecolourcontrast:Disable();
			end;
		end)
		f.allowcolours:SetChecked(mrpSaved.Options.AllowColours)
		f.allowcolours:SetPoint( "TOPLEFT", f.profilevieweresc, "BOTTOMLEFT", 0, 2 )

        -- SUB-BUTTONS FOR COLOURS
        -- Use custom class colour in tooltip
		f.tooltipclasscolours = newCheckbox(
				L["opt_tooltipclasscolours"], -- Label
				L["opt_tooltipclasscolours_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.TooltipClassColours = value
		end)
		f.tooltipclasscolours:SetHeight(22)
		f.tooltipclasscolours:SetWidth(22)
		f.tooltipclasscolours:SetChecked(mrpSaved.Options.TooltipClassColours)
		f.tooltipclasscolours:SetPoint( "TOPLEFT", f.allowcolours, "BOTTOMLEFT", 20, 2 )
		-- Run on startup to disable these checkboxes if colours are disabled.
		if(mrpSaved.Options.AllowColours == false) then
			f.tooltipclasscolours:Disable();
		end

        -- Increase colour contrast
		f.increasecolourcontrast = newCheckbox(
				L["opt_increasecolourcontrast"], -- Label
				L["opt_increasecolourcontrast_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.IncreaseColourContrast = value
		end)
		f.increasecolourcontrast:SetHeight(22)
		f.increasecolourcontrast:SetWidth(22)
		f.increasecolourcontrast:SetChecked(mrpSaved.Options.IncreaseColourContrast)
		f.increasecolourcontrast:SetPoint( "TOPLEFT", f.tooltipclasscolours, "BOTTOMLEFT", 0, 2 )
		-- Run on startup to disable these checkboxes if colours are disabled.
		if(mrpSaved.Options.AllowColours == false) then
			f.increasecolourcontrast:Disable();
		end

        -- Autoplay music
		f.autoplaymusic = newCheckbox(
				L["opt_autoplaymusic"], -- Label
				L["opt_autoplaymusic_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.AutoplayMusic = value 
		end)
		f.autoplaymusic:SetChecked(mrpSaved.Options.AutoplayMusic)
		f.autoplaymusic:SetPoint( "TOPLEFT", f.increasecolourcontrast, "BOTTOMLEFT", -20, 2 )

        -- Change header colour
        f.headercolour = CreateFrame("Frame", "MyRolePlayOptionsPanel_HeaderColourFrame", f)
        f.headercolour:SetPoint( "TOPLEFT", f.autoplaymusic, "BOTTOMRIGHT", -23, -5 )
        f.headercolour:SetHeight(15)
        f.headercolour:SetWidth(175)
        local headercolourtexture = f.headercolour:CreateTexture("MyRolePlayOptionsPanel_HeaderColourTexture", "ARTWORK")
        headercolourtexture:SetTexture("Interface\\AddOns\\MyRolePlay\\Artwork\\HeaderBackground.blp")
        headercolourtexture:SetAllPoints(f.headercolour)
        if(mrpSaved.Options["headerColour"]) then
            headercolourtexture:SetVertexColor(mrpSaved.Options["headerColour"]["r"], mrpSaved.Options["headerColour"]["g"], mrpSaved.Options["headerColour"]["b"]);
        else
            mrpSaved.Options["headerColour"] = {}
            if mrp:IsMainlineClient() then
                mrpSaved.Options["headerColour"]["r"] = 0.69
                mrpSaved.Options["headerColour"]["g"] = 0.29
                mrpSaved.Options["headerColour"]["b"] = 1
                headercolourtexture:SetVertexColor(0.69, 0.29, 1)
            elseif mrp:IsClassicClient() then
                mrpSaved.Options["headerColour"]["r"] = 1
                mrpSaved.Options["headerColour"]["g"] = 0
                mrpSaved.Options["headerColour"]["b"] = 0.101
                headercolourtexture:SetVertexColor(1, 0, 0.101)
			elseif mrp:IsBurningCrusadeClient() then
				mrpSaved.Options["headerColour"]["r"] = 0.4
                mrpSaved.Options["headerColour"]["g"] = 0.73
                mrpSaved.Options["headerColour"]["b"] = 0.06
                headercolourtexture:SetVertexColor(0.4, 0.73, 0.06)
			elseif mrp:IsWrathClient() then
				mrpSaved.Options["headerColour"]["r"] = 0.25
                mrpSaved.Options["headerColour"]["g"] = 0.61
                mrpSaved.Options["headerColour"]["b"] = 0.96
                headercolourtexture:SetVertexColor(0.25, 0.61, 0.96)
			elseif mrp:IsCataClient() then
				mrpSaved.Options["headerColour"]["r"] = 1
                mrpSaved.Options["headerColour"]["g"] = 0
                mrpSaved.Options["headerColour"]["b"] = 0.101
                headercolourtexture:SetVertexColor(1, 0, 0.101)
            end
        end

        f.headercolour.fs = f.headercolour:CreateFontString( nil, "ARTWORK", "GameFontNormalSmall" )
        f.headercolour.fs:SetJustifyH( "LEFT" )
        f.headercolour.fs:SetText( L["opt_headercolour_label"] )
        f.headercolour.fs:SetParent( f.headercolour )
        f.headercolour.fs:SetShadowColor( 0, 0, 0, 0.1 )
        f.headercolour.fs:SetAllPoints()
        f.headercolour.fs:SetPoint("TOPLEFT", f.headercolour, "TOPLEFT", 0, 3 )

        f.headercolour:SetScript("OnMouseDown", function (self)
            StaticPopupDialogs[ "MRP_HEADERCOLOUR_RELOAD" ] = {
                text = format( L["opt_headercolour_popup"] ),
                button1 = OKAY or "OK",
                whileDead = true,
                timeout = 0,
            }
            StaticPopup_Show( "MRP_HEADERCOLOUR_RELOAD" )
            local savedR, savedG, savedB
            if(mrpSaved.Options["headerColour"]) then
                savedR = mrpSaved.Options["headerColour"]["r"]
                savedG = mrpSaved.Options["headerColour"]["g"]
                savedB = mrpSaved.Options["headerColour"]["b"]
            else
                savedR, savedG, savedB = 0.69, 0.29, 1 -- Default purple, no previous values set.
            end
            mrp:ShowColorPicker(savedR, savedG, savedB, 1, mrp_HeaderColourChangedCallback)
        end )

        -- "Tooltip Settings" header
        f.TooltipDesignHeader = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
        f.TooltipDesignHeader:SetJustifyH( "LEFT" )
        f.TooltipDesignHeader:SetJustifyV( "TOP" )
        f.TooltipDesignHeader:SetPoint( "TOPLEFT", f.autoplaymusic, "BOTTOMLEFT", 2, -30 )
        f.TooltipDesignHeader:SetText( L["opt_tooltipdesign_header"] )

        -- Tooltip Style dropdown
        f.ttstyle = CreateFrame( "Frame", "MyRolePlayOptionsPanel_TTStyle", f, "UIDropDownMenuTemplate" )
        f.ttstyle:SetPoint( "TOPLEFT", f.TooltipDesignHeader, "BOTTOMLEFT", -20, -20 )
        f.ttstyle.type = CONTROLTYPE_DROPDOWN
        f.ttstyle.isoption = "TooltipStyle"
        UIDropDownMenu_SetWidth( f.ttstyle, 125 )
        f.ttstyle:EnableMouse( true )
        f.ttstyle.label = "ttstyle"

        -- "Tooltip style" header
        f.ttstyle.capt = f.ttstyle:CreateFontString( "MyRolePlayOptionsPanel_TTStyleLabel", "OVERLAY", "GameFontHighlightSmall" )
        f.ttstyle.capt:SetJustifyH( "LEFT" )
        f.ttstyle.capt:SetJustifyV( "TOP" )
        f.ttstyle.capt:SetPoint( "TOPLEFT", f.TooltipDesignHeader, "BOTTOMLEFT", 0, -7 )
        f.ttstyle.capt:SetText( L["opt_tooltipstyle_header"] )

        f.ttstyle.dd = CreateFrame( "Button", "MyRolePlayOptionsPanel_TTStyleDropDown", f, "UIDropDownListTemplate" )
        MyRolePlayOptionsPanel_TTStyleButton:SetScript( "OnClick", function( self )
            if DropDownList1:IsVisible() then
                DropDownList1:Hide()
            else
                EasyMenu( mrp.optionscomboboxfields[ "ttstyle" ], MyRolePlayOptionsPanel_TTStyleDropDown, MyRolePlayOptionsPanel_TTStyle, 0, 5 )
                UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_TTStyle, mrpSaved.Options.TooltipStyle )
            end
        end )
        f.ttstyle.Disable = UIDropDownMenu_DisableDropDown
        f.ttstyle.Enable = UIDropDownMenu_EnableDropDown
        f.ttstyle.RefreshValue = function( self )
            UIDropDownMenu_SetSelectedValue( self, mrpSaved.Options.TooltipStyle )
            MyRolePlayOptionsPanel_TTStyleText:SetText( mrp.optionscomboboxfields[ "ttstyle" ][ mrpSaved.Options.TooltipStyle + 1 ].text )
        end
        MyRolePlayOptionsPanel_TTStyleText:SetText( mrp.optionscomboboxfields[ "ttstyle" ][ mrpSaved.Options.TooltipStyle + 1 ].text )
		
		-- Tooltip Name colour dropdown
        f.ttnamecolour = CreateFrame( "Frame", "MyRolePlayOptionsPanel_TTNameColour", f, "UIDropDownMenuTemplate" )
        f.ttnamecolour:SetPoint( "TOPLEFT", f.ttstyle, "TOPRIGHT", -30, 0 )
        f.ttnamecolour.type = CONTROLTYPE_DROPDOWN
        f.ttnamecolour.isoption = "TooltipNameColour"
        UIDropDownMenu_SetWidth( f.ttnamecolour, 125 )
        f.ttnamecolour:EnableMouse( true )
        f.ttnamecolour.label = "ttnamecolour"
		
		f.ttnamecolour.dd = CreateFrame( "Button", "MyRolePlayOptionsPanel_TTNameColourDropDown", f, "UIDropDownListTemplate" )
        MyRolePlayOptionsPanel_TTNameColourButton:SetScript( "OnClick", function( self )
            if DropDownList1:IsVisible() then
                DropDownList1:Hide()
            else
                EasyMenu( mrp.optionscomboboxfields[ "ttnamecolour" ], MyRolePlayOptionsPanel_TTNameColourDropDown, MyRolePlayOptionsPanel_TTNameColour, 0, 5 )
                UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_TTNameColour, mrpSaved.Options.TooltipNameColour )
            end
        end )
        f.ttnamecolour.Disable = UIDropDownMenu_DisableDropDown
        f.ttnamecolour.Enable = UIDropDownMenu_EnableDropDown
        f.ttnamecolour.RefreshValue = function( self )
            UIDropDownMenu_SetSelectedValue( self, mrpSaved.Options.TooltipNameColour )
            MyRolePlayOptionsPanel_TTNameColourText:SetText( mrp.optionscomboboxfields[ "ttnamecolour" ][ mrpSaved.Options.TooltipNameColour + 1 ].text )
        end
        MyRolePlayOptionsPanel_TTNameColourText:SetText( mrp.optionscomboboxfields[ "ttnamecolour" ][ mrpSaved.Options.TooltipNameColour + 1 ].text )

        -- Tooltip Name colour header
        f.ttnamecolour.capt = f.ttnamecolour:CreateFontString( "MyRolePlayOptionsPanel_TTNameColourLabel", "OVERLAY", "GameFontHighlightSmall" )
        f.ttnamecolour.capt:SetJustifyH( "LEFT" )
        f.ttnamecolour.capt:SetJustifyV( "TOP" )
        f.ttnamecolour.capt:SetPoint( "TOPLEFT", f.ttstyle.capt, "TOPRIGHT", 80, 0 )
        f.ttnamecolour.capt:SetText( L["Tooltip name colour:"] )


        -- Max lines slider
        f.maxlinesslider = CreateFrame("Slider", "MyRolePlayOptionsPanel_MaxLinesSlider", f, "OptionsSliderTemplate")
        getglobal(f.maxlinesslider:GetName() .. 'Low'):SetText('1');
        getglobal(f.maxlinesslider:GetName() .. 'High'):SetText('10');
        f.maxlinesslider:SetPoint( "TOPLEFT", f.ttstyle, "BOTTOMLEFT", 15, -10 )
        f.maxlinesslider.type = CONTROLTYPE_SLIDER
        f.maxlinesslider:SetMinMaxValues(1, 10)
        f.maxlinesslider:SetValueStep(1)
        f.maxlinesslider:SetObeyStepOnDrag(true)
        f.maxlinesslider.defaultValue = mrp.DefaultOptions.MaxLinesSlider
        f.maxlinesslider:SetValue(mrpSaved.Options.MaxLinesSlider or mrp.DefaultOptions.MaxLinesSlider)
        f.maxlinesslider.sliderLabel = f.maxlinesslider:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall")
        f.maxlinesslider.sliderLabel:SetPoint("TOP", f.maxlinesslider.Thumb, "BOTTOM", 0, 5);
        f.maxlinesslider.sliderLabel:SetText( tostring(f.maxlinesslider:GetValue()))
        f.maxlinesslider:SetScript("OnValueChanged", function()
            mrpSaved.Options.MaxLinesSlider = f.maxlinesslider:GetValue()
            f.maxlinesslider.sliderLabel:SetText( tostring(f.maxlinesslider:GetValue()))
        end);

        getglobal(f.maxlinesslider:GetName() .. 'Text'):SetText( L["opt_maxtooltiplines_header"] )
        f.maxlinesslider.tooltipText = 'Change the maximum number of lines displayed for the currently and OOC fields.'

        -- Show in tooltip... header
        f.ShowInTooltipHeader = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
        f.ShowInTooltipHeader:SetJustifyH( "LEFT" )
        f.ShowInTooltipHeader:SetJustifyV( "TOP" )
        f.ShowInTooltipHeader:SetPoint( "TOPLEFT", f.maxlinesslider, "BOTTOMLEFT", 2, -15 )
        f.ShowInTooltipHeader:SetText( L["opt_showintooltip_header"] )
			
		-- Show custom class names in tooltip
		f.classnames = newCheckbox(
				L["opt_classnames"], -- Label
				L["opt_classnames_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ClassNames = value 
		end)
		f.classnames:SetChecked(mrpSaved.Options.ClassNames)
		f.classnames:SetPoint( "TOPLEFT", f.ShowInTooltipHeader, "BOTTOMLEFT", 2, -4 )
			
		-- Show OOC line in tooltip
		f.showooc = newCheckbox(
				L["opt_showooc"], -- Label
				L["opt_showooc_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowOOC = value 
		end)
		f.showooc:SetChecked(mrpSaved.Options.ShowOOC)
		f.showooc:SetPoint( "TOPLEFT", f.classnames, "BOTTOMLEFT", 0, 2 )
			
		-- Show version line checkbox
		f.showversion = newCheckbox(
				L["opt_showversion"], -- Label
				L["opt_showversion_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowVersion = value;
				if value == true then
					f.showfullversiontext:Enable();
					f.showtarget:Enable();
				else
					f.showfullversiontext:Disable();
					f.showtarget:Disable();
				end;
		end)
		f.showversion:SetChecked(mrpSaved.Options.ShowVersion)
		f.showversion:SetPoint( "TOPLEFT", f.showooc, "BOTTOMLEFT", 0, 2 )
			
		-- Show target in tooltip (mini checkbox)
		f.showtarget = newCheckbox(
				L["opt_showtarget"], -- Label
				L["opt_showtarget_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowTarget = value
		end)
		f.showtarget:SetHeight(22)
		f.showtarget:SetWidth(22)
		f.showtarget:SetChecked(mrpSaved.Options.ShowTarget)
		f.showtarget:SetPoint( "TOPLEFT", f.showversion, "BOTTOMLEFT", 20, 2 )
		if(mrpSaved.Options.ShowVersion == false) then
			f.showtarget:Disable();
		end
			
		-- Show full version text (mini checkbox)
		f.showfullversiontext = newCheckbox(
				L["opt_showfullversiontext"], -- Label
				L["opt_showfullversiontext_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowFullVersionText = value
		end)
		f.showfullversiontext:SetHeight(22)
		f.showfullversiontext:SetWidth(22)
		f.showfullversiontext:SetChecked(mrpSaved.Options.ShowFullVersionText)
		f.showfullversiontext:SetPoint( "TOPLEFT", f.showtarget, "BOTTOMLEFT", 0, 2 )
		if(mrpSaved.Options.ShowVersion == false) then
			f.showfullversiontext:Disable();
		end
			
		-- Show icon in tooltip
		f.showiconintt = newCheckbox(
				L["opt_showiconintt"], -- Label
				L["opt_showiconintt_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowIconInTT = value 
		end)
		f.showiconintt:SetChecked(mrpSaved.Options.ShowIconInTT)
		f.showiconintt:SetPoint( "TOPLEFT", f.showfullversiontext, "BOTTOMLEFT", -20, 2 )
			
		-- Show guild rank checkbox
		f.showguildnames = newCheckbox(
				L["opt_showguildnames"], -- Label
				L["opt_showguildnames_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowGuildNames = value 
		end)
		f.showguildnames:SetChecked(mrpSaved.Options.ShowGuildNames)
		f.showguildnames:SetPoint( "TOPLEFT", f.showiconintt, "BOTTOMLEFT", 0, 2 )
			
		-- Hide TT in encounters checkbox
		f.hidettinencounters = newCheckbox(
				L["opt_hidettinencounters"], -- Label
				L["opt_hidettinencounters_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.HideTTInEncounters = value 
		end)
		f.hidettinencounters:SetChecked(mrpSaved.Options.HideTTInEncounters)
		f.hidettinencounters:SetPoint( "TOPLEFT", f.showguildnames, "BOTTOMLEFT", 0, 2 )
			
		-- Show legacy level checkbox
		f.showlegacylevel = newCheckbox(
				L["opt_showlegacylevel"], -- Label
				L["opt_showlegacylevel_tt"],   -- Tooltip
				function(self, value) mrpSaved.Options.ShowLegacyLevel = value 
		end)
		f.showlegacylevel:SetChecked(mrpSaved.Options.ShowLegacyLevel)
		f.showlegacylevel:SetPoint( "TOPLEFT", f.hidettinencounters, "BOTTOMLEFT", 0, 2 )
			
		-- Show pronouns checkbox
		f.showpronouns = newCheckbox(
				L["opt_showpronouns"],
				L["opt_showpronouns_tt"],
				function(self, value) mrpSaved.Options.ShowPronouns = value 
		end)
		f.showpronouns:SetChecked(mrpSaved.Options.ShowPronouns)
		f.showpronouns:SetPoint( "TOPLEFT", f.showlegacylevel, "BOTTOMLEFT", 0, 2 )
		
		-- Show voice reference checkbox
		f.showvoicereference = newCheckbox(
				L["opt_showvoicereference"],
				L["opt_showvoicereference_tt"],
				function(self, value) mrpSaved.Options.ShowVoiceReference = value 
		end)
		f.showvoicereference:SetChecked(mrpSaved.Options.ShowVoiceReference)
		f.showvoicereference:SetPoint( "TOPLEFT", f.showpronouns, "BOTTOMLEFT", 0, 2 )
			
		-- COLUMN 2 --
			
		-- "Chat Settings" header
		f.ChatSettingsHeader = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
		f.ChatSettingsHeader:SetJustifyH( "LEFT" )
		f.ChatSettingsHeader:SetJustifyV( "TOP" )
		f.ChatSettingsHeader:SetPoint( "LEFT", f.BasicFunctionalityHeader, "RIGHT", 210, 0 )
		f.ChatSettingsHeader:SetText( L["opt_chatsettings_header"] )

		-- "Show RP names in..." header
		f.RPNamesHeader = f:CreateFontString( nil, "OVERLAY", "GameFontHighlightSmall" )
		f.RPNamesHeader:SetJustifyH( "LEFT" )
		f.RPNamesHeader:SetJustifyV( "TOP" )
		f.RPNamesHeader:SetPoint( "TOPLEFT", f.ChatSettingsHeader, "BOTTOMLEFT", 0, -4 )
		f.RPNamesHeader:SetText( L["opt_rpnamesinchat_header"] )
			
		-- Show RP Names in /say
		f.rpchatsay = newCheckbox(
			L["opt_rpchatnamesay"], -- Label
			L["opt_rpchatnamesay_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatSay = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatsay:SetChecked(mrpSaved.Options.RPChatSay)
		f.rpchatsay:SetPoint( "TOPLEFT", f.RPNamesHeader, "BOTTOMLEFT", -2, -2 )
			
		-- Show RP Names in /whisper
		f.rpchatwhisper = newCheckbox(
			L["opt_rpchatnamewhisper"], -- Label
			L["opt_rpchatnamewhisper_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatWhisper = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatwhisper:SetChecked(mrpSaved.Options.RPChatWhisper)
		f.rpchatwhisper:SetPoint( "TOPLEFT", f.rpchatsay, "TOPRIGHT", 80, 0 )

		-- Show RP Names in /emote
		f.rpchatemote = newCheckbox(
			L["opt_rpchatnameemote"], -- Label
			L["opt_rpchatnameemote_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatEmote = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatemote:SetChecked(mrpSaved.Options.RPChatEmote)
		f.rpchatemote:SetPoint( "TOPLEFT", f.rpchatwhisper, "TOPRIGHT", 80, 0 )

		-- Show RP Names in /yell
		f.rpchatyell = newCheckbox(
			L["opt_rpchatnameyell"], -- Label
			L["opt_rpchatnameyell_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatYell = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatyell:SetChecked(mrpSaved.Options.RPChatYell)
		f.rpchatyell:SetPoint( "TOPLEFT", f.rpchatsay, "BOTTOMLEFT", 0, 2 )

		-- Show RP Names in /party
		f.rpchatparty = newCheckbox(
			L["opt_rpchatnameparty"], -- Label
			L["opt_rpchatnameparty_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatParty = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatparty:SetChecked(mrpSaved.Options.RPChatParty)
		f.rpchatparty:SetPoint( "TOPLEFT", f.rpchatyell, "TOPRIGHT", 80, 0 )
		
		-- Show RP Names in /raid
		f.rpchatraid = newCheckbox(
			L["opt_rpchatnameraid"], -- Label
			L["opt_rpchatnameraid_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatRaid = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatraid:SetChecked(mrpSaved.Options.RPChatRaid)
		f.rpchatraid:SetPoint( "TOPLEFT", f.rpchatparty, "TOPRIGHT", 80, 0 )
			
		-- Show RP Names in /guild and /officer
		f.rpchatguild = newCheckbox(
			L["opt_rpchatnameguild"], -- Label
			L["opt_rpchatnameguild_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.RPChatGuild = value;
			mrp:RefreshRPChats();
		end)
		f.rpchatguild:SetChecked(mrpSaved.Options.RPChatGuild)
		f.rpchatguild:SetPoint( "TOPLEFT", f.rpchatyell, "BOTTOMLEFT", 0, 2 )

		-- Highlight emotes contained in **
		f.highlightemotes = newCheckbox(
			L["opt_highlightemotes"], -- Label
			L["opt_highlightemotes_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.HighlightEmotes = value 
		end)
		f.highlightemotes:SetChecked(mrpSaved.Options.HighlightEmotes)
		f.highlightemotes:SetPoint( "TOPLEFT", f.rpchatguild, "BOTTOMLEFT", 0, -10 )

        -- Highlight OOC contained in (())
		f.highlightooc = newCheckbox(
			L["opt_highlightooc"], -- Label
			L["opt_highlightooc_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.HighlightOOC = value 
		end)
		f.highlightooc:SetChecked(mrpSaved.Options.HighlightOOC)
		f.highlightooc:SetPoint( "TOPLEFT", f.highlightemotes, "BOTTOMLEFT", 0, 2 )

        -- Show icons in chat
		f.showiconsinchat = newCheckbox(
			L["opt_showiconsinchat"], -- Label
			L["opt_showiconsinchat_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ShowIconsInChat = value 
		end)
		f.showiconsinchat:SetChecked(mrpSaved.Options.ShowIconsInChat)
		f.showiconsinchat:SetPoint( "TOPLEFT", f.highlightooc, "BOTTOMLEFT", 0, -10 )

        -- "Profile Display" header
        f.dh = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
        f.dh:SetJustifyH( "LEFT" )
        f.dh:SetJustifyV( "TOP" )
        f.dh:SetPoint( "TOPLEFT", f.showiconsinchat, "BOTTOMLEFT", 2, -10 )
        f.dh:SetText( L["opt_disp_header"] )

        -- Show Personality Traits tab checkbox
		f.traits = newCheckbox(
			L["opt_traits"], -- Label
			L["opt_traits_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ShowTraitsInBrowser = value;
			if value == true then
				mrpSaved.Options.ShowTraitsInBrowser = true
                MyRolePlayBrowseFrameTab2:Show()
                MyRolePlayBrowseFrameTab3:SetPoint( "LEFT", MyRolePlayBrowseFrameTab2, "RIGHT", -15, 0 )
                if mrp.BFShown then
                    mrp:RequestForBF()
                end
			else
				mrpSaved.Options.ShowTraitsInBrowser = false
                if mrp.BFShown and MyRolePlayBrowseFrame.Personality:IsVisible() then
                    mrp:TabSwitchBF( "Appearance" )
                end
                MyRolePlayBrowseFrameTab2:Hide()
                MyRolePlayBrowseFrameTab3:SetPoint( "LEFT", MyRolePlayBrowseFrameTab1, "RIGHT", -15, 0 )
			end;
		end)
		f.traits:SetChecked(mrpSaved.Options.ShowTraitsInBrowser)
		f.traits:SetPoint( "TOPLEFT", f.dh, "BOTTOMLEFT", -2, -2 )
		
		-- Show biography tab checkbox
		f.biog = newCheckbox(
			L["opt_biog"], -- Label
			L["opt_biog_tt"],   -- Tooltip
			function(self, value) mrpSaved.Options.ShowBiographyInBrowser = value;
			if value == true then
				mrpSaved.Options.ShowBiographyInBrowser = true
                 MyRolePlayBrowseFrameTab3:Show()
                if mrp.BFShown then
                    mrp:RequestForBF()
                end
			else
				mrpSaved.Options.ShowBiographyInBrowser = false
                if mrp.BFShown and MyRolePlayBrowseFrame.Biography:IsVisible() then
                    mrp:TabSwitchBF( "Appearance" )
                end
                MyRolePlayBrowseFrameTab3:Hide()
			end;
		end)
		f.biog:SetChecked(mrpSaved.Options.ShowBiographyInBrowser)
		f.biog:SetPoint( "TOPLEFT", f.traits, "BOTTOMLEFT", 0, 2 )

        -- Glance position drop down box
        f.glanceposition = CreateFrame( "Button", "MyRolePlayOptionsPanel_GlancePosition", f, "UIDropDownMenuTemplate" )
        f.glanceposition:SetPoint( "TOPLEFT", f.dh, "BOTTOMLEFT", -17, -73 )
        f.glanceposition.type = CONTROLTYPE_DROPDOWN
        f.glanceposition.isoption = "GlancePosition"
        UIDropDownMenu_SetWidth( f.glanceposition, 130 )
        f.glanceposition:EnableMouse( true )
        f.glanceposition.label = "glanceposition"

        f.glanceposition.capt = f.glanceposition:CreateFontString( "MyRolePlayOptionsPanel_GlancePositionLabel", "OVERLAY", "GameFontHighlightSmall" )
        f.glanceposition.capt:SetJustifyH( "LEFT" )
        f.glanceposition.capt:SetJustifyV( "TOP" )
        f.glanceposition.capt:SetPoint( "TOPLEFT", f.biog, "BOTTOMLEFT", 2, -10 )
        f.glanceposition.capt:SetText( L["opt_glanceposition_header"] )

        f.glanceposition.dd = CreateFrame( "Button", "MyRolePlayOptionsPanel_GlancePositionDropDown", f, "UIDropDownListTemplate" )
        MyRolePlayOptionsPanel_GlancePositionButton:SetScript( "OnClick", function( self )
            if DropDownList1:IsVisible() then
                DropDownList1:Hide()
            else
                EasyMenu( mrp.optionscomboboxfields[ "glanceposition" ], MyRolePlayOptionsPanel_GlancePositionDropDown, MyRolePlayOptionsPanel_GlancePosition, 0, 5 )
                UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_GlancePosition, mrpSaved.Options.GlancePosition )
            end
        end )
        f.glanceposition.Disable = UIDropDownMenu_DisableDropDown
        f.glanceposition.Enable = UIDropDownMenu_EnableDropDown
        f.glanceposition.RefreshValue = function( self )
            UIDropDownMenu_SetSelectedValue( self, mrpSaved.Options.GlancePosition )
            MyRolePlayOptionsPanel_GlancePositionText:SetText( mrp.optionscomboboxfields[ "glanceposition" ][ mrpSaved.Options.GlancePosition + 1 ].text )
        end
        MyRolePlayOptionsPanel_GlancePositionText:SetText( mrp.optionscomboboxfields[ "glanceposition" ][ mrpSaved.Options.GlancePosition + 1 ].text )

        -- Height drop down box
        f.ahunit = CreateFrame( "Button", "MyRolePlayOptionsPanel_HeightUnit", f, "UIDropDownMenuTemplate" )
        f.ahunit:SetPoint( "TOPLEFT", f.glanceposition, "BOTTOMLEFT", 0, -14 )
        f.ahunit.type = CONTROLTYPE_DROPDOWN
        f.ahunit.isoption = "HeightUnit"
        UIDropDownMenu_SetWidth( f.ahunit, 130 )
        f.ahunit:EnableMouse( true )
        f.ahunit.label = "ahunit"

        f.ahunit.capt = f.ahunit:CreateFontString( "MyRolePlayOptionsPanel_HeightUnitLabel", "OVERLAY", "GameFontHighlightSmall" )
        f.ahunit.capt:SetJustifyH( "LEFT" )
        f.ahunit.capt:SetJustifyV( "TOP" )
        f.ahunit.capt:SetPoint( "TOPLEFT", f.glanceposition, "BOTTOMLEFT", 18, 0 )
        f.ahunit.capt:SetText( L["opt_displayheight_header"] )

        f.ahunit.dd = CreateFrame( "Button", "MyRolePlayOptionsPanel_HeightUnitDropDown", f, "UIDropDownListTemplate" )
        MyRolePlayOptionsPanel_HeightUnitButton:SetScript( "OnClick", function( self )
            if DropDownList1:IsVisible() then
                DropDownList1:Hide()
            else
                EasyMenu( mrp.optionscomboboxfields[ "ahunit" ], MyRolePlayOptionsPanel_HeightUnitDropDown, MyRolePlayOptionsPanel_HeightUnit, 0, 5 )
                UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_HeightUnit, mrpSaved.Options.HeightUnit )
            end
        end )
        f.ahunit.Disable = UIDropDownMenu_DisableDropDown
        f.ahunit.Enable = UIDropDownMenu_EnableDropDown
        f.ahunit.RefreshValue = function( self )
            UIDropDownMenu_SetSelectedValue( self, mrpSaved.Options.HeightUnit )
            MyRolePlayOptionsPanel_HeightUnitText:SetText( mrp.optionscomboboxfields[ "ahunit" ][ mrpSaved.Options.HeightUnit + 1 ].text )
        end
        MyRolePlayOptionsPanel_HeightUnitText:SetText( mrp.optionscomboboxfields[ "ahunit" ][ mrpSaved.Options.HeightUnit + 1 ].text )

        -- Weight drop down box
        f.awunit = CreateFrame( "Frame", "MyRolePlayOptionsPanel_WeightUnit", f, "UIDropDownMenuTemplate" )
        f.awunit:SetPoint( "TOPLEFT", f.ahunit, "BOTTOMLEFT", 0, -12 )
        f.awunit.type = CONTROLTYPE_DROPDOWN
        f.awunit.isoption = "WeightUnit"
        UIDropDownMenu_SetWidth( f.awunit, 130 )
        f.awunit:EnableMouse( true )
        f.awunit.label = "awunit"

        f.awunit.capt = f.awunit:CreateFontString( "MyRolePlayOptionsPanel_WeightUnitLabel", "OVERLAY", "GameFontHighlightSmall" )
        f.awunit.capt:SetJustifyH( "LEFT" )
        f.awunit.capt:SetJustifyV( "TOP" )
        f.awunit.capt:SetPoint( "TOPLEFT", f.ahunit, "BOTTOMLEFT", 17, 3 )
        f.awunit.capt:SetText( L["opt_displayweight_header"] )

        f.awunit.dd = CreateFrame( "Button", "MyRolePlayOptionsPanel_WeightUnitDropDown", f, "UIDropDownListTemplate" )
        MyRolePlayOptionsPanel_WeightUnitButton:SetScript( "OnClick", function( self )
            if DropDownList1:IsVisible() then
                DropDownList1:Hide()
            else
                EasyMenu( mrp.optionscomboboxfields[ "awunit" ], MyRolePlayOptionsPanel_WeightUnitDropDown, MyRolePlayOptionsPanel_WeightUnit, 0, 5 )
                UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_WeightUnit, mrpSaved.Options.WeightUnit )
            end
        end )
        f.awunit.Disable = UIDropDownMenu_DisableDropDown
        f.awunit.Enable = UIDropDownMenu_EnableDropDown
        f.awunit.RefreshValue = function( self )
            UIDropDownMenu_SetSelectedValue( self, mrpSaved.Options.WeightUnit )
            MyRolePlayOptionsPanel_WeightUnitText:SetText( mrp.optionscomboboxfields[ "awunit" ][ mrpSaved.Options.WeightUnit + 1 ].text )
        end
        MyRolePlayOptionsPanel_WeightUnitText:SetText( mrp.optionscomboboxfields[ "awunit" ][ mrpSaved.Options.WeightUnit + 1 ].text )

        -- "Automatically change profile on.. label"
        f.fch = f:CreateFontString( nil, "OVERLAY", "GameFontNormalLarge" )
        f.fch:SetJustifyH( "LEFT" )
        f.fch:SetJustifyV( "TOP" )
        f.fch:SetPoint( "TOPLEFT", f.awunit, "BOTTOMLEFT", 17, -10 )
        f.fch:SetText( L["opt_ac_header"] )

        -- "Shapeshifting" checkbox
		f.formac = newCheckbox(
			L["opt_formac"], -- Label
			"",   -- Tooltip
			function(self, value) mrpSaved.Options.FormAutoChange = value 
		end)
		f.formac:SetChecked(mrpSaved.Options.FormAutoChange)
		f.formac:SetPoint( "TOPLEFT", f.fch, "BOTTOMLEFT", -2, 0 )

        -- "Changing equipment set" checkbox; disabled in Classic client.
        if mrp:IsMainlineClient() then
			f.equipac = newCheckbox(
				L["opt_equipac"], -- Label
				"",   -- Tooltip
				function(self, value) mrpSaved.Options.EquipSetAutoChange = value 
			end)
			f.equipac:SetChecked(mrpSaved.Options.EquipSetAutoChange)
			f.equipac:SetPoint( "TOPLEFT", f.formac, "BOTTOMLEFT", 0, 2 )
        end
		
		MyRolePlayOptionsPanel:SetScale(.95)

        -- frame, okay, cancel, default, refresh
        --BlizzardOptionsPanel_OnLoad( f, nil, nil, mrp.OptionsPanelDefaultFunction, nil )
        InterfaceOptions_AddCategory( f, true )

        if not mrpSaved.Options.Enabled then
            for k, v in ipairs( MyRolePlayOptionsPanel.controls ) do
                if not v.avoiddisabling then
                    v:Disable()
                end
            end
        end

        mrp.CreateOptionsPanel = nop
    end
end

function mrp.OptionsPanelDefaultFunction()
    for k, v in ipairs( MyRolePlayOptionsPanel.controls ) do
        if type( v.setFunc ) == "function" then
            v.setFunc( v.defaultValue )
        elseif type( v.RefreshValue ) == "function" then
            mrpSaved.Options[ v.isoption ] = mrp.DefaultOptions[ v.isoption ]
            v:RefreshValue()
        elseif type( v.SetValue ) == "function" then
            v.SetValue( v.defaultValue)
        end
    end
end

function mrp.GlancePositionCBClick( self )
    mrp:DebugSpam("glancepositioncbclick: %s", self.value or "<nil>")
    mrpSaved.Options.GlancePosition = self.value
    UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_GlancePosition, self.value )
    mrp:UpdateGlanceIconPosition()
    if mrp.BFShown then
        mrp:UpdateBrowseFrame()
    end
end

function mrp.AHUnitCBClick( self )
    mrp:DebugSpam("ahunitcbclick: %s", self.value or "<nil>")
    mrpSaved.Options.HeightUnit = self.value
    UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_HeightUnit, self.value )
    if mrp.BFShown then
        mrp:UpdateBrowseFrame()
    end
end

function mrp.AWUnitCBClick( self )
    mrp:DebugSpam("awunitcbclick: %s", self.value or "<nil>")
    mrpSaved.Options.WeightUnit = self.value
    UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_WeightUnit, self.value )
    if mrp.BFShown then
        mrp:UpdateBrowseFrame()
    end
end

function mrp.TTStyleCBClick( self )
    mrp:DebugSpam("ttstylecbclick: %s", self.value or "<nil>")
    mrpSaved.Options.TooltipStyle = self.value
    UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_TTStyle, self.value )
    if mrp.TTShown then
        mrp:UpdateTooltip( mrp.TTShown )
    end
end

function mrp.TTNameColourCBClick( self )
    mrp:DebugSpam("ttnamecolourcbclick: %s", self.value or "<nil>")
    mrpSaved.Options.TooltipNameColour = self.value
    UIDropDownMenu_SetSelectedValue( MyRolePlayOptionsPanel_TTNameColour, self.value )
end

mrp.optionscomboboxfields = {
    ["glanceposition"] = {
        { text = L["glance_position_right"], value = 0, func = mrp.GlancePositionCBClick },
        { text = L["glance_position_left"], value = 1, func = mrp.GlancePositionCBClick },
    },
    ["ahunit"] = {
        { text = L["cm_format_name"], value = 0, func = mrp.AHUnitCBClick },
        { text = L["m_format_name"], value = 1, func = mrp.AHUnitCBClick },
        { text = L["ftin_format_name"], value = 2, func = mrp.AHUnitCBClick },
    },
    ["awunit"] = {
        { text = L["kg_format_name"], value = 0, func = mrp.AWUnitCBClick },
        { text = L["lb_format_name"], value = 1, func = mrp.AWUnitCBClick },
        { text = L["stlb_format_name"], value = 2, func = mrp.AWUnitCBClick },
    },
    ["ttstyle"] = {
        { text = L["ttstyle_0_name"], value = 0, func = mrp.TTStyleCBClick },
        { text = L["ttstyle_1_name"], value = 1, func = mrp.TTStyleCBClick },
        { text = L["ttstyle_2_name"], value = 2, func = mrp.TTStyleCBClick },
        { text = L["ttstyle_3_name"], value = 3, func = mrp.TTStyleCBClick },
    },
    ["ttnamecolour"] = {
        { text = L["Player selected (default)"], value = 0, func = mrp.TTNameColourCBClick },
        { text = L["PvP status / faction"], value = 1, func = mrp.TTNameColourCBClick },
        { text = L["Class colour"], value = 2, func = mrp.TTNameColourCBClick },
    },
}